@@ -192,7 +192,7 @@ class BaseFeatureManager(ABC):
             dependencies=self.config_helper.get_direct_dependencies(feature_name),
             raw_data=self.raw_data,
         )
-        series = transformer_object._transform(self.dataframe, transformer)
+        series = transformer_object._transform(self.dataframe, transformer, is_training)
         if is_training:
             self.transformer_dict[feature_name] = transformer_object.transformer
 
@@ -276,7 +276,7 @@ class BaseFeatureManager(ABC):
                 f"Features {undefined_features} are not defined in feature config."
             )
 
-    def transform_new_samples(self, raw_data_samples, transforming_features):
+    def transform_new_samples(self, raw_data_samples, transforming_features=None):
         self.set_raw_data(raw_data_samples)
         self.initialize_dataframe()
         if transforming_features is None:
@@ -298,6 +298,26 @@ class BaseFeatureManager(ABC):
         self.compute_transforming_features(
             transforming_features_and_dependencies, is_training=False
         )
+
+        # Convert types (defined in feature_config) for relevant columns/features.
+        # self.dataframe contains all base features in the code which might not exist
+        # when the feature manger was first ran. For that reason, we only care about
+        # the features that existed at the first ran, according to feature_config.
+        for column in self.feature_metadata:
+            if column not in self.dataframe.columns:
+                continue
+            dtype = self.feature_metadata[column].dtype
+            if dtype == DType.DATETIME:
+                self.dataframe[column] = pd.to_datetime(self.dataframe[column])
+            elif dtype == DType.BOOL:
+                # well, when convert an object to bool, "False" is converted to True
+                # https://stackoverflow.com/a/48350163
+                self.dataframe[column] = self.dataframe[column] == "True"
+            else:
+                self.dataframe[column] = self.dataframe[column].astype(
+                    PANDAS_DTYPE_MAPPING[dtype]
+                )
+
         return self.dataframe
 
     def set_raw_data(self, raw_data_samples: Any):
@@ -349,13 +369,17 @@ class BaseTransformingFeature(ABC):
         self.dependencies = dependencies
         self.raw_data = raw_data
         self.transformer = None
+        self.is_training = True
 
-    def _transform(self, dataframe, transformer=None):
-        logger.info(f"Computing feature {self.name} in pandas ...")
+    def _transform(self, dataframe, transformer=None, is_training=True):
+        # only output messages in training mode
+        if is_training:
+            logger.info(f"Computing feature {self.name} in pandas ...")
         # This is to make sure that _transform_ methods do not use any columns other
         # than dependencies.
         df = dataframe[self.dependencies]
         self.transformer = transformer
+        self.is_training = is_training
         if transformer is None:
             self.fit(dataframe)
         return self.transform(df)
